@@ -21,6 +21,7 @@
     #include <QLabel>
     #include <QVBoxLayout>
 #endif
+#include <QHash>
 #include <QDesktopServices>
 #include <QLabel>
 #include <QVBoxLayout>
@@ -93,6 +94,8 @@ QString CommonStatic::GetSettingsFolder()
 }
 
 QList<Contact*> CommonStatic::ContactsCache;
+QHash<QString, int> CommonStatic::ContactsCacheNumbers;
+QHash<int, Contact*> CommonStatic::ContactsCacheIds;
 void CommonStatic::LoadContactsCache()
 {
     ContactsLoader loader;
@@ -101,11 +104,12 @@ void CommonStatic::LoadContactsCache()
 
 Contact* CommonStatic::GetContact(int id)
 {
-    foreach (Contact* c, ContactsCache){
-        if (c->Id == id)
-            return c;
-    }
-    return NULL;
+    return ContactsCacheIds.value(id, NULL);
+}
+
+bool CommonStatic::ContactExists(QString number)
+{
+    return ContactsCacheNumbers.contains(number);
 }
 
 bool CommonStatic::IsMouseOver(QWidget* w)
