@@ -27,7 +27,7 @@
     using namespace QtMobility;
 #endif
 
-class ContactsLoader : public QThread
+class ContactsLoader
 {
 public:
     void run();
