@@ -33,7 +33,7 @@
     </message>
     <message>
         <location filename="contactswindow.cpp" line="88"/>
-        <location filename="contactswindow.cpp" line="156"/>
+        <location filename="contactswindow.cpp" line="180"/>
         <source>Address book (%1)</source>
         <translation type="unfinished">Rubrica (%1)</translation>
     </message>
@@ -154,12 +154,20 @@
         <translation type="unfinished">Invia SMS al gruppo</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="232"/>
+        <location filename="mainwindow.cpp" line="221"/>
+        <location filename="mainwindow.cpp" line="263"/>
         <source>Confirm remove</source>
         <translation type="unfinished">Conferma rimozione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="233"/>
+        <location filename="mainwindow.cpp" line="222"/>
+        <source>You have %1 invalid number(s) in your groups.
+Remove invalid numbers?</source>
+        <translation type="unfinished">Ci sono %1 numeri non validi nei tuoi gruppi.
+Rimuovere i numeri non validi?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="264"/>
         <source>Remove group %1?</source>
         <translation type="unfinished">Rimuovere il gruppo %1?</translation>
     </message>
